######################
Analytic Budget Module
######################

The *Analytic Budget Module* provides the ability to set budgets for analytic
accounts over a defined period of time.
These budgets can then be used to track the total amount from relevant
transactions against the budgeted amount.

.. toctree::
   :maxdepth: 2

   usage
   design
